nsim.analyses1 package
======================

Submodules
----------

nsim.analyses1.epochs module
----------------------------

.. automodule:: nsim.analyses1.epochs
    :members:
    :undoc-members:
    :show-inheritance:

nsim.analyses1.freq module
--------------------------

.. automodule:: nsim.analyses1.freq
    :members:
    :undoc-members:
    :show-inheritance:

nsim.analyses1.misc module
--------------------------

.. automodule:: nsim.analyses1.misc
    :members:
    :undoc-members:
    :show-inheritance:

nsim.analyses1.phase module
---------------------------

.. automodule:: nsim.analyses1.phase
    :members:
    :undoc-members:
    :show-inheritance:

nsim.analyses1.plots module
---------------------------

.. automodule:: nsim.analyses1.plots
    :members:
    :undoc-members:
    :show-inheritance:

nsim.analyses1.pyeeg module
---------------------------

.. automodule:: nsim.analyses1.pyeeg
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: nsim.analyses1
    :members:
    :undoc-members:
    :show-inheritance:
